@@ -64,7 +64,7 @@ FIELD_TYPES = {
 }
 
 
-def ModelSchemaField(field: Any) -> tuple:
+def ModelSchemaField(field: Any, schema_name: str) -> tuple:
     default = Required
     default_factory = None
     description = None
@@ -96,8 +96,12 @@ def ModelSchemaField(field: Any) -> tuple:
                 if Promise in type(v).__mro__:
                     v = str(v)
                 enum_choices[v] = k
+
+            enum_prefix = (
+                f"{schema_name.replace('_', '')}{field.name.title().replace('_', '')}"
+            )
             python_type = Enum(  # type: ignore
-                f"{field.name.title().replace('_', '')}Enum",
+                f"{enum_prefix}Enum",
                 enum_choices,
                 module=__name__,
             )
