@@ -10,7 +10,6 @@ from django.contrib.postgres.fields import JSONField
 from django.contrib.postgres.indexes import GinIndex
 from django.contrib.postgres.search import SearchVectorField
 from django.utils.translation import gettext_lazy as _
-from django.utils import timezone
 
 from .fields import ListField, NotNullRestrictedCharField
 
@@ -208,8 +207,8 @@ class Attachment(models.Model):
 
 
 class FoodChoices(models.TextChoices):
-    BANANA = "ba", "A delicious yellow Banana"
-    APPLE = "ap", "A delicious red Apple"
+    BANANA = "ba", _("A delicious yellow Banana")
+    APPLE = "ap", _("A delicious red Apple")
 
 
 class GroupChoices(models.IntegerChoices):
@@ -236,3 +235,18 @@ class Searchable(models.Model):
 
     class Meta:
         indexes = [GinIndex(fields=["search_vector"], name="search_vector_idx")]
+
+
+class ExtendedModel(models.Model):
+    name = models.CharField(max_length=128)
+
+    class Meta:
+        abstract = True
+
+
+class Expert(ExtendedModel):
+    cases = models.ManyToManyField("Case", related_name="related_experts")
+
+
+class Case(ExtendedModel):
+    details = models.TextField()
